==> mozile-0.7.0.zip: mozile/modules/UndoRedo/UndoRedo.js <==
// Copyright (C) 2005 The Mozile Team. See http://mozile.mozdev.org/ for details.

Mozile.prototype.undoStack=new Array();Mozile.prototype.undoCounter=0;Mozile.prototype.storeState=function(command){var f=new Array();f["File"]="UndoRedo/UndoRedo.js";f["Function"]="Mozile.storeState()";if(this.changesSaved==true){this.status(f,1,"Editing");this.changesSaved=false;}
this.keyCounter=0;var selection=window.getSelection();var states=new Array();var editorArray;for(var i=0;i<this.editorList.length;i++){editorArray=new Array(this.editorList[i],this.editorList[i].cloneNode(true));states.push(editorArray);}
var selectionArray=this.storeSelection();if(this.undoCounter<this.undoStack.length-1){this.undoStack=this.undoStack.slice(0,this.undoCounter+1);}
var stateArray=new Array(command,states,selectionArray)
this.undoStack.push(stateArray);this.undoCounter=this.undoStack.length-1;return true;}
Mozile.prototype.restoreState=function(index){var f=new Array();f["File"]="UndoRedo/UndoRedo.js";f["Function"]="Mozile.restoreState()";var command=this.undoStack[index][0];var states=this.undoStack[index][1];var selectionArray=this.undoStack[index][2];var i,j=0;var editor,editorCopy;for(j=0;j<states.length;j++){editor=states[j][0];editorCopy=states[j][1];while(editor.childNodes.length){editor.removeChild(editor.firstChild);}
var children=editorCopy.childNodes;for(i=0;i<children.length;i++){editor.appendChild(children[i].cloneNode(true));}}
this.restoreSelection(selectionArray);window.getSelection().collapseToEnd();return true;}
var mozileUndo=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Undo, label=Undo, tooltip='Undo the previous action', accelerator='Command-Z', image='"+mozile.root+"images/undo.png'");mozileUndo.command=function(){if(mozile.undoCounter<=0){return false;}
else{mozile.undoCounter--;mozile.restoreState(mozile.undoCounter);return true;}}
var mozileRedo=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Redo, label=Redo, tooltip='Redo the next action', accelerator='Command-Shift-Z', image='"+mozile.root+"images/redo.png'");mozileRedo.command=function(){if(mozile.undoCounter>=mozile.undoStack.length-1){return false;}
else{mozile.undoCounter++;mozile.restoreState(mozile.undoCounter);return true;}}
mozile.registerModule("UndoRedo","1.0.0");

==> mozile-0.7.1.zip: mozile/modules/UndoRedo/UndoRedo.js <==
// Copyright (C) 2006 The Mozile Team. See http://mozile.mozdev.org/ for details.

Mozile.prototype.undoStack=new Array();Mozile.prototype.undoCounter=0;Mozile.prototype.storeState=function(command){var f=new Array();f["File"]="UndoRedo/UndoRedo.js";f["Function"]="Mozile.storeState()";if(this.changesSaved==true){this.status(f,1,"Editing");this.changesSaved=false;}
this.keyCounter=0;var selection=mozile.getSelection();var states=new Array();var editorArray;for(var i=0;i<this.editorList.length;i++){editorArray=new Array(this.editorList[i],this.editorList[i].cloneNode(true));states.push(editorArray);}
var selectionArray=this.storeSelection();if(this.undoCounter<this.undoStack.length-1){this.undoStack=this.undoStack.slice(0,this.undoCounter+1);}
var stateArray=new Array(command,states,selectionArray)
this.undoStack.push(stateArray);this.undoCounter=this.undoStack.length-1;return true;}
Mozile.prototype.restoreState=function(index){var f=new Array();f["File"]="UndoRedo/UndoRedo.js";f["Function"]="Mozile.restoreState()";var command=this.undoStack[index][0];var states=this.undoStack[index][1];var selectionArray=this.undoStack[index][2];var i,j=0;var editor,editorCopy;for(j=0;j<states.length;j++){editor=states[j][0];editorCopy=states[j][1];while(editor.childNodes.length){editor.removeChild(editor.firstChild);}
var children=editorCopy.childNodes;for(i=0;i<children.length;i++){editor.appendChild(children[i].cloneNode(true));}}
this.restoreSelection(selectionArray);window.getSelection().collapseToEnd();return true;}
if(mozile.rootCommandList){var mozileUndo=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Undo, label=Undo, tooltip='Undo the previous action', accelerator='Command-Z', image='"+mozile.root+"images/undo.png'");mozileUndo.command=function(){if(mozile.undoCounter<=0){return false;}
else{mozile.undoCounter--;mozile.restoreState(mozile.undoCounter);return true;}}
var mozileRedo=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Redo, label=Redo, tooltip='Redo the next action', accelerator='Command-Shift-Z', image='"+mozile.root+"images/redo.png'");mozileRedo.command=function(){if(mozile.undoCounter>=mozile.undoStack.length-1){return false;}
else{mozile.undoCounter++;mozile.restoreState(mozile.undoCounter);return true;}}}
mozile.registerModule("UndoRedo","1.0.0");
